full_name = input( "Enter Your Name : " ).split()

def shortName( full_name ):
    short_name = ''
    words = len( full_name )

    if words >= 3:
        
        for word in full_name[ : (words -1) ]:
            
            short_name += word[0].upper() + "."
        
        short_name += full_name[ -1 ].capitalize()
        
        return short_name

# print( short_name )
        
print( shortName(full_name) )




def numToText( listOfNumbers, space=32, specialChar=95 ):
    """ if a = 1, b = 2, c = 3 and " " = 27 and "_" = 28
    example "bad " = 2 1 4 27 
    
    below is example how to use
    test = [23, 5, 12, 12, 27, 20, 8, 5, 27, 6, 12, 1,]
    print( assciToText( test, space=27, specialChar=28 ) )
    
    tutorial
    youtube:- 
    """

    text = ""

    for num in listOfNumbers:
        if num == space:
            text += " "
        elif num == specialChar:
            text += "_"
        else:
            text += chr( num + 96 )

    return text


if __name__ == '__main__':
    pass




from HackerGprat import clear
from pytube import YouTube
import os

def yt(videourl, path="./Output"):

    clear()
    
    print("🔌Connecting...🔐 \n")
    
    yt = YouTube(videourl)
    yt = yt.streams.filter(progressive=True, file_extension='mp4').order_by('resolution').desc().first()
    
    if not os.path.exists(path):
        print("Creating Folder...\n")
        os.makedirs(path)

    print("⏬ Downloading...⏳\n")
    yt.download(path)
    print("✅ SucessFully Downloaded...\n")



# url = 'https://www.youtube.com/watch?v=r2giUilvkBQ&list=PLC3y8-rFHvwg2-q6Kvw3Tl_4xhxtIaNlY&index=45'
# yt_download( url )

# urls = []


def yt_download( url ):
    
    if type( url ) == str:
        yt( url )
        
    elif type( url ) == list:

        # todo - detected links : 
        # todo - total file going to be downladed
        # downloading {i} 
        
        for link in url:
            yt( link )
    else:
        print("See The Docs & Try Again")






# from plyer import notification
from plyer import notification

def desktop_notification( title="Title", message="Enter Your Message", timeout=10 ):
    notification.notify(
                title = title,
                message = message,
                timeout = 10
            )
    



import setuptools

with open( "README.md" , 'r', encoding="utf-8") as fh:
    long_description = fh.read()

    # print( long_description )
    
setuptools.setup(
    name = "HackerGprat",
    version = "0.3.3",
    author = "HackerGprat",
    author_email = "Sorry@gmail.com",   # "https://youtube.com/HackerGprat" # test it working or not
    description = "Here You can find Userfull fucntion which you need in your every python packages.",
    long_description = long_description,
    long_description_content_type = "text/markdown",
    url = "https://github.com/HackerGprat/HackerGprat-PIP-Library/",
    
    install_requires =['numpy',
                       'pandas',
                       'matplotlib',
                       'scipy',
                       'binance',
                       'python-binance',
                       'pillow',
                       'setuptools',
                       'wheel',
                       'requests',
                       'ipython',
                       'scikit-learn',
                       'sklearn',
                       'seaborn',
                       'bs4',
                       'plyer'
                    #    '--upgrade pip' error while buidling dont use this
        ],
    
    project_urls={
        "Bug Tracker" : "https://github.com/HackerGprat/HackerGprat-PIP-Library/issues",
        "Website" : "https://hackergprat.github.io",
        "Instagram": "https://instagram.com/HackerGprat",
        "YouTube" : "https://youtube.com/HackerGprat"
    },
    
    classifiers = [
        "Programming Language :: Python :: 3", 
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],

    # test it before upload / working or not?
    # Testing = [
    #     "Cool Name :: HackerGprat"
    #     "Cool Nam1 :: HackerGprat1"
    #     "Cool Nam2 :: HackerGprat2"
    # ],
    
    
    package_dir = { "" : "src" },
    packages = setuptools.find_packages( where="src" ),
    python_requires =">=3.6",
    
)


    
    
